@@ -1,16 +1,15 @@
-from typing import Any, Dict, Tuple, List, Set, Union
 import warnings
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 
-from tqdm import tqdm
-
+from aiida.orm import Group
 from aiida.orm.nodes import Node
 from aiida.orm.querybuilder import QueryBuilder
-
 from optimade.models import EntryResource
 from optimade.server.entry_collections import EntryCollection
 from optimade.server.exceptions import BadRequest, NotFound
 from optimade.server.query_params import EntryListingQueryParams, SingleEntryQueryParams
 from optimade.server.warnings import UnknownProviderProperty
+from tqdm import tqdm
 
 from aiida_optimade.common import CausationError
 from aiida_optimade.common.logger import LOGGER
@@ -33,6 +32,7 @@ class AiidaCollection(EntryCollection):
     def __init__(
         self,
         entities: Union[str, List[str]],
+        group: Optional[str],
         resource_cls: EntryResource,
         resource_mapper: ResourceMapper,
     ):
@@ -43,6 +43,7 @@ class AiidaCollection(EntryCollection):
         )
 
         self.entities = entities if isinstance(entities, list) else [entities]
+        self.group = group
 
         # "Cache"
         self._data_available: int = None
@@ -294,7 +295,9 @@ class AiidaCollection(EntryCollection):
         return results, more_data_available
 
     @staticmethod
-    def _prepare_query(node_types: List[str], **kwargs) -> QueryBuilder:
+    def _prepare_query(
+        node_types: List[str], group: Optional[str] = None, **kwargs
+    ) -> QueryBuilder:
         """Workhorse function to prepare an AiiDA QueryBuilder query"""
         for key in kwargs:
             if key not in {"filters", "order_by", "limit", "project", "offset"}:
@@ -312,7 +315,11 @@ class AiidaCollection(EntryCollection):
         project = kwargs.get("project", [])
 
         query = QueryBuilder(limit=limit, offset=offset)
-        query.append(Node, project=project, filters=filters)
+        if group:
+            query.append(Group, filters={"label": group}, tag="group")
+            query.append(Node, with_group="group", project=project, filters=filters)
+        else:
+            query.append(Node, project=project, filters=filters)
         query.order_by(order_by)
 
         return query
@@ -322,7 +329,7 @@ class AiidaCollection(EntryCollection):
         LOGGER.debug(
             "Using QueryBuilder to get ALL projected values from found entries."
         )
-        query = self._prepare_query(self.entities, **kwargs)
+        query = self._prepare_query(self.entities, self.group, **kwargs)
         res = query.all()
         del query
         return res
@@ -330,7 +337,7 @@ class AiidaCollection(EntryCollection):
     def _perform_count(self, **kwargs) -> int:
         """Instantiate new QueryBuilder object and perform count()"""
         LOGGER.debug("Using QueryBuilder to COUNT all found entries.")
-        query = self._prepare_query(self.entities, **kwargs)
+        query = self._prepare_query(self.entities, self.group, **kwargs)
         res = query.count()
         del query
         return res
