@@ -2,28 +2,24 @@
 from typing import Union
 
 from fastapi import APIRouter, Depends, Request
-
-from optimade.models import (
-    ErrorResponse,
-    StructureResponseMany,
-    StructureResponseOne,
-)
-from optimade.server.config import CONFIG, SupportedBackend
+from optimade.models import ErrorResponse, StructureResponseMany, StructureResponseOne
+from optimade.server.config import SupportedBackend
 from optimade.server.entry_collections.mongo import MongoCollection
 from optimade.server.mappers.structures import (
     StructureMapper as OptimadeStructureMapper,
 )
 from optimade.server.query_params import EntryListingQueryParams, SingleEntryQueryParams
 
+from aiida_optimade.config import CONFIG
 from aiida_optimade.entry_collections import AiidaCollection
 from aiida_optimade.mappers import StructureMapper
 from aiida_optimade.models import StructureResource
-from aiida_optimade.routers.utils import get_entries, get_single_entry, close_session
-
+from aiida_optimade.routers.utils import close_session, get_entries, get_single_entry
 
 ROUTER = APIRouter(redirect_slashes=True)
 
 STRUCTURES = AiidaCollection(
+    group=CONFIG.query_group,
     entities=["data.core.cif.CifData.", "data.core.structure.StructureData."],
     resource_cls=StructureResource,
     resource_mapper=StructureMapper,
